@@ -5,7 +5,7 @@
 /* Copyright (c) Philip Hazel, 1991 - 2010 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: October 2013 */
 
 /* This is the header file for the output routines. */
 
@@ -141,6 +141,7 @@ extern BOOL   n_invertright;          /* Ditto right */
 extern int    n_lastacc;              /* For last note in chord */
 extern b_notestr *n_lastnote;         /* Last note set */
 extern int    n_length;               /* Length of current note */
+extern int    n_longrestmid;          /* Long rest mid point */
 extern int    n_masq;                 /* Masquerade for current note */
 extern int    n_maxaccleft;           /* Max accidental left in chord */
 extern int    n_maxpitch;             /* Max pitch of current note/chord */
